pub struct Ref<'lib, T: 'lib> { /* private fields */ }Expand description
Safe wrapper around cont reference.
This type is intended to be used only inside structures implementing SymBorApi trait.
In other cases you can as well use normal Rust reference.
Implementations